==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangClassLoaderNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangClassLoaderNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e480f736e905a9a9 soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5fdefineClass0$18193167273d8b91(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5ffindBootstrapClass$b3f9ad588b047cbc(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5ffindLoadedClass$998f67296bf4f93d(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5fgetCallerClassLoader$dbbe685012ec2053(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$v$6fcaf7cc5e0871de(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangClassLoaderNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangClassLoaderNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e480f736e905a9a9 soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5fdefineClass0$18193167273d8b91(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5ffindBootstrapClass$b3f9ad588b047cbc(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5ffindLoadedClass$998f67296bf4f93d(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$java__5flang__5fClassLoader__5fgetCallerClassLoader$dbbe685012ec2053(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$method$v$6fcaf7cc5e0871de(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangClassLoaderNative_H_ */
